/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2018, 2022 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name        : Config_TAUD0_user.c
* Component Version: 1.4.0
* Device(s)        : R7F701690
* Description      : This file implements device driver for Config_TAUD0.
***********************************************************************************************************************/
/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "r_cg_userdefine.h"
#include "Config_TAUD0.h"
/* Start user code for include. Do not edit comment generated here */
#include "ics2_RH850F1KM-S1.h"
#include "DTL_IOLIB.h"
#include "DTL_control.h"
#include "mathf.h"
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Start user code for global. Do not edit comment generated here */
extern volatile uint8_t  * gp_uart0_tx_address;       /* uart0 transmit data address */
extern volatile uint16_t   g_uart0_tx_count;          /* uart0 transmit data number */
//uint32_t  s4_pwm_onoff = 1;
#define  TWOPI   (3.14159265f*2.0f)

//#define  T2001C
//#define  T2003C
//#define  T2005C
  #define  INV_TARGET



#if  defined(T2001C)
  #define  K_CUR_RANGE  (10.0f)   // 50m ohm x 5
  #define  K_VOL_RANGE  (111.0f)  // 111V max

#elif defined(T2003C)
  #define  K_CUR_RANGE  (100.0f) //  5m ohm x 5
  #define  K_VOL_RANGE  (111.0f)  // 111V max

#elif defined(T2005C)
  #define  K_CUR_RANGE  (500.0f)  //  1m ohm x 5
  #define  K_VOL_RANGE  (111.0f)  // 111V max

#elif defined(INV_TARGET)         //  1m ohm x 10
  #define  K_CUR_RANGE  (250.0f)
  #define  K_VOL_RANGE  (126.0f)  // 126V max
#endif

#define  K_TMR_GAIN     (2.5f)

float     _fIu1AD  = 0.0f;
float     _fIv1AD  = 0.0f;
float     _fIw1AD  = 0.0f;
float     _fSinPAD  = 0.0f;
float     _fSinNAD  = 0.0f;
float     _fCosPAD  = 0.0f;
float     _fCosNAD  = 0.0f;
float     _fVtempAD = 0.0f;
float     _fIdcAD   = 0.0f;
volatile float     _fVdcAD  = 0.0f;
volatile float     _fVctrlAD = 0.0f;

float     _fSinAD   = 0.0f;
float     _fCosAD   = 0.0f;
float     _fSinOfs  = 0.0f;
float     _fCosOfs  = 0.0f;
float     _fSinGain = 1.0f;  // 1.0f FIXed
float     _fCosGain = 1.0f;  

float     _fMuRef  = 0.0f;
float     _fMvRef  = 0.0f;
float     _fMwRef  = 0.0f;
#if 1
float     _fM      = 0.01f;
#endif
uint32_t  u4IdcADRaw = 0;
uint32_t  u4IdcOfs   = 2072;   // IɃItZbg␳̂

#define   F_MATH_TWOPI   (2.0f*3.14159265f)

extern float     _fThermistorTemp;
extern uint16_t _u2FlagError;
extern float    _fPe;

/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_Config_TAUD0_Create_UserInit
* Description  : This function adds user code after initializing the TAUD0 channel
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void R_Config_TAUD0_Create_UserInit(void)
{
    /* Start user code for user init. Do not edit comment generated here */
    int32_t i;

    for(i=0;i<18;i++)
    {
        ics_tx.txbuf[i] = 0x55;
    }

    // Module inter-connection definition
    PIC0.REG202  = 0x0888001C;  // Connect from timer ch4-9 to ch10-15
    PIC0.HIZCEN0 &= ~0x04;      // Disable GateBlock by WDTAnNMI
    PIC0.HIZCEN0 &= ~0x40;      // Disable GateBlock by INTADCA0ERR
    PIC0.HIZCEN0 |=  0x01;      // Enable GateBlock by  TAPA0ESO 
    
    TAPA0.CTL0   &= ~0x0C;      // clear DCN/DCP (resetTAPATHASIN edge)
    TAPA0.CTL0   |=  0x08;      // Falling edge
    TAPA0.CTL0   |=  0x10;      // TATA0DCM = 1

    TAPA0.ACWE    =  0x01;      // ACWE bit set   Write enable
    TAPA0.ACTS    =  0x01;      // ACTS bit set   HiZ start trigger

    // Clock settings
    TAUD0.TPS = 0x0000;         // CK0,CK1,CK2,CK3 = CLK/1
    TAUD0.BRS = 0x00;           // CK3 = CK3_PRE/1

    // Master channel CH2  PWM output function CH register settings
  //TAUD0.CDR2  = 7999;         // Period  80MHz/10kHz =8000
    TAUD0.CDR2  = 4999;         // Period  80MHz/16kHz =5000
    TAUD0.CMOR2 = 0x0801;       // 
    TAUD0.CMUR2 = 0x00;         // 

    // Slave channel CH4-9
#if 0   // for 10kHz
    TAUD0.CDR4  = 2000;         // U-phase on timing
    TAUD0.CMOR4 = 0x0409;       // 
    TAUD0.CMUR4 = 0x00;         // 
    TAUD0.CDR5  = 6000;         // U-phase on timing
    TAUD0.CMOR5 = 0x0409;       // 
    TAUD0.CMUR5 = 0x00;         // 
    TAUD0.CDR6  = 2000;         // V-phase on timing
    TAUD0.CMOR6 = 0x0409;       // 
    TAUD0.CMUR6 = 0x00;         // 
    TAUD0.CDR7  = 6000;         // V-phase on timing
    TAUD0.CMOR7 = 0x0409;       // 
    TAUD0.CMUR7 = 0x00;         // 
    TAUD0.CDR8  = 2000;         // W-phase on timing
    TAUD0.CMOR8 = 0x0409;       // 
    TAUD0.CMUR8 = 0x00;         // 
    TAUD0.CDR9  = 6000;         // W-phase on timing
    TAUD0.CMOR9 = 0x0409;       // 
    TAUD0.CMUR9 = 0x00;         // 
#else  // for 16kHz
    TAUD0.CDR4  = 1250;         // U-phase on timing
    TAUD0.CMOR4 = 0x0409;       // 
    TAUD0.CMUR4 = 0x00;         // 
    TAUD0.CDR5  = 3750;         // U-phase on timing
    TAUD0.CMOR5 = 0x0409;       // 
    TAUD0.CMUR5 = 0x00;         // 
    TAUD0.CDR6  = 1250;         // V-phase on timing
    TAUD0.CMOR6 = 0x0409;       // 
    TAUD0.CMUR6 = 0x00;         // 
    TAUD0.CDR7  = 3750;         // V-phase on timing
    TAUD0.CMOR7 = 0x0409;       // 
    TAUD0.CMUR7 = 0x00;         // 
    TAUD0.CDR8  = 1250;         // W-phase on timing
    TAUD0.CMOR8 = 0x0409;       // 
    TAUD0.CMUR8 = 0x00;         // 
    TAUD0.CDR9  = 3750;         // W-phase on timing
    TAUD0.CMOR9 = 0x0409;       // 
    TAUD0.CMUR9 = 0x00;         // 
#endif
    // 1 Phase PWM output function
 // TAUD0.CDR10  = 80;          // Any value
 // TAUD0.CMOR10 = 0x0109;      // Any value
 // TAUD0.CMUR10 = 0x03;        // Any value
    TAUD0.CDR11  = 80;          // U phase deadtime  ;0.5us=40,  1.0us=80
    TAUD0.CMOR11 = 0x0109;      // 
    TAUD0.CMUR11 = 0x03;        // 
 // TAUD0.CDR12  = 80;          // Any value
 // TAUD0.CMOR12 = 0x0109;      // Any value
 // TAUD0.CMUR12 = 0x03;        // Any value
    TAUD0.CDR13  = 80;          // V phase deadtime  ;0.5us=40,  1.0us=80
    TAUD0.CMOR13 = 0x0109;      // 
    TAUD0.CMUR13 = 0x03;        // 
 // TAUD0.CDR14  = 80;          // Any value
 // TAUD0.CMOR14 = 0x0109;      // Any value
 // TAUD0.CMUR14 = 0x03;        // Any value
    TAUD0.CDR15  = 80;          // W phase deadtime  ;0.5us=40,  1.0us=80
    TAUD0.CMOR15 = 0x0109;      // 
    TAUD0.CMUR15 = 0x03;        // 

    // -----------------------------
    TAUD0.TOE    = 0x0000;      // output disable
    TAUD0.TO     = 0x0000;      // 
    TAUD0.TOM    = 0xFFF0;      // 
    TAUD0.TOC    = 0xFC00;      // 
    TAUD0.TOL    = 0x0000;      // Active level (0:positive logic)
    TAUD0.TDE    = 0xFC00;      // Deadtime output enable
    TAUD0.TDM    = 0xFC00;      // Deadtime output settings
    TAUD0.TDL    = 0xA800;      // Deadtime setting
    TAUD0.TRE    = 0x0000;      // Realtime output setting
  //TAUD0.TRE    = 0xFC00;      // Realtime output enalbe)
    TAUD0.TRO    = 0x0000;      // 
    TAUD0.TRC    = 0x0000;      // 
  //TAUD0.TME    = 0x0000;      // 
    TAUD0.TME    = 0xFC00;      // output TRO data
    TAUD0.RDE    = 0x03F4;      // Sync update enable
    TAUD0.RDS    = 0x0000;      // 
    TAUD0.RDM    = 0x0000;      // 
    TAUD0.RDC    = 0x0000;      // 

    // Output enable
    TAUD0.TOE    = 0xFC00;      // Output enable
    TAUD0.TS     = 0xFFF4;      // Counter start

    /* End user code. Do not edit comment generated here */
}

/***********************************************************************************************************************
* Function Name: r_Config_TAUD0_channel2_interrupt
* Description  : This function is TAUD02 interrupt service routine
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
#pragma interrupt r_Config_TAUD0_channel2_interrupt(enable=false, channel=9, fpu=true, callt=false)
void r_Config_TAUD0_channel2_interrupt(void)
{
    /* Start user code for r_Config_TAUD0_channel2_interrupt. Do not edit comment generated here */
    uint32_t  u4_data0 = 0;  // VCh0:Iu,   VCh1:Iv
    uint32_t  u4_data1 = 0;  // VCh2:Iw,   VCh3:Vdc
    uint32_t  u4_data2 = 0;  // VCh4:SinP, VCh5:SinN
    uint32_t  u4_data3 = 0;  // VCh6:CosP, VCh7:CosN
    uint32_t  u4_data4 = 0;  // VCh8:Vctrl,VCh9:Temp
    uint32_t  u4_data5 = 0;  // VCh10:Idc

    // Wait for end of conversion
    while ((ADCA0.SGSTR.UINT32&0x0200)!=0)  { /* no code */ }

    // Get ADC data
  #ifdef INV_TARGET
    u4_data0 = ADCA0.DR00.UINT32;
    _fIu1AD  =  (((float)(u4_data0 & 0x0FFF)-2048.0f))/2048.0f*K_CUR_RANGE;
    _fIv1AD  =  (((float)(u4_data0 >> 16   )-2048.0f))/2048.0f*K_CUR_RANGE;

    u4_data1 = ADCA0.DR02.UINT32;
    _fIw1AD  =  (((float)(u4_data1 & 0x0FFF)-2048.0f))/2048.0f*K_CUR_RANGE;
    _fVdcAD  = ((float)(u4_data1 >> 16))/4096.0f*K_VOL_RANGE;
  #else
    u4_data0 = ADCA0.DR00.UINT32;
    _fIu1AD  = -(((float)(u4_data0 & 0x0FFF)-2048.0f))/2048.0f*K_CUR_RANGE;
    _fIv1AD  = -(((float)(u4_data0 >> 16   )-2048.0f))/2048.0f*K_CUR_RANGE;

    u4_data1 = ADCA0.DR02.UINT32;
    _fIw1AD  = -(((float)(u4_data1 & 0x0FFF)-2048.0f))/2048.0f*K_CUR_RANGE;
    _fVdcAD  = ((float)(u4_data1 >> 16))/4096.0f*K_VOL_RANGE;
  #endif

    u4_data2 = ADCA0.DR04.UINT32;
    _fSinPAD = ((float)(u4_data2 & 0x0FFF)-2048.0f)/2048.0f*K_TMR_GAIN;
    _fSinNAD = ((float)(u4_data2 >>   16)-2048.0f)/2048.0f*K_TMR_GAIN;

    u4_data3 = ADCA0.DR06.UINT32;
    _fCosPAD = ((float)(u4_data3 & 0x0FFF)-2048.0f)/2048.0f*K_TMR_GAIN;
    _fCosNAD = ((float)(u4_data3 >>   16)-2048.0f)/2048.0f*K_TMR_GAIN;

    u4_data4 = ADCA0.DR08.UINT32;
    _fVctrlAD= ((float)(u4_data4 & 0x0FFF))/4096.0f*K_VOL_RANGE;
    _fVtempAD= ((float)(u4_data4 >> 16));

    u4_data5 = ADCA0.DR10.UINT32;
    u4IdcADRaw = u4_data5 & 0x0FFC;
    _fIdcAD  = ((float)(u4_data5 & 0x0FFC)-u4IdcOfs)/2048.0f*83.33f;

    _fSinAD  = (_fSinPAD  - _fSinNAD - _fSinOfs) * _fSinGain;
    _fCosAD  = (_fCosPAD  - _fCosNAD - _fCosOfs) * _fCosGain;


    DTL_carrier_control();

    {
        _fPe = _fPe + 50.0f * F_MATH_TWOPI / 16000.0f;
        if (_fPe>F_MATH_TWOPI) { _fPe = _fPe - F_MATH_TWOPI; }
        _fMuRef = _fM * sinf(_fPe);
        _fMvRef = _fM * sinf(_fPe-F_MATH_TWOPI/3.0f*1.0f);
        _fMwRef = _fM * sinf(_fPe-F_MATH_TWOPI/3.0f*2.0f);
    }
	
    //== Gate block ==================================================
    if ((_u2ModeSystem==S_MODE_RUN)||(_u2ModeSystem==S_MODE_ADADJ))
    {
        DTL_inverter_TAUD0_start_pwm();
    }
    else
    {
        DTL_inverter_TAUD0_stop_pwm();
    }

    //== PWM reference set ===========================================
    DTL_inverter_TAUD0_set_uvw_3shunt(_fMuRef, _fMvRef, _fMwRef);
    /* End user code. Do not edit comment generated here */
}

/* Start user code for adding. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
